/*******************************************************************************
 * Part of "Intel(R) Active Management Technology (Intel(R) AMT)
 *                   User Notification Service (UNS)"
 *
 * Copyright (c) 2007 - 2008 Intel Corp.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions, and the following disclaimer,
 *    without modification.
 * 2. Redistributions in binary form must reproduce at minimum a disclaimer
 *    substantially similar to the "NO WARRANTY" disclaimer below
 *    ("Disclaimer") and any redistribution must be conditioned upon
 *    including a substantially similar Disclaimer requirement for further
 *    binary redistribution.
 * 3. Neither the names of the above-listed copyright holders nor the names
 *    of any contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * Alternatively, this software may be distributed under the terms of the
 * GNU General Public License ("GPL") version 2 as published by the Free
 * Software Foundation.
 *
 * NO WARRANTY
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR CONTRIBUTORS BE LIABLE FOR SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGES.
 *******************************************************************************/

#ifndef _AT_STATUS_PROXY_H
#define _AT_STATUS_PROXY_H
#include "EventHistory.h"
#include "IPCiATStatus.h"
#include "UNSEventLogger.h"
#include "FWULCommand.h"
#include "MNGCommand.h"
#include "AMTStatusData.h"
#include "AMTStatusColl.h"
#ifdef WITH_TPM
#include "TPMStatusData.h"
#include "TPMStatusColl.h"
#endif
#include "Semaphore.h"

class ATStatus
{
public:
	// Constructor
	ATStatus(bool verbose = false, UNSEventLogger *pLogger = NULL);
	// dtor
	virtual ~ATStatus();

	// initialization routine
	bool Init();
	// closing routine
	void Deinit();

	// Set a pointer to the Logger.
	void SetLogger(UNSEventLogger *pLogger) { m_pLogger = pLogger; }

	// data manipulators
	bool SetAMTData(const AMTStatusData &amtData, bool bLogging = false);
	bool IsAmtSku();
	bool IsAmtKnown();
	bool IsAmtEnabled();
	bool IsAmtFundamental();
#ifdef WITH_TPM
	bool SetTPMData(const TPMStatusData &tpmData, bool bLogging = false);
	bool IsTpmSku();
#endif
	bool AsyncEvent(ATEvents::EventNode event);

private:
	void clearData();
	bool putData();
	IPCiATStatus::Enablement enablementFromData() const;
	void logEvent(const ATEvents::EventNode &event);
	bool readSkuInfo();
	void filterAsyncEvents(std::list<ATEvents::EventNode> &events);

	FWULCommand     m_fwulCommand;
	MNGCommand      m_mngCommand;
	MEFWCAPS_SKU    m_skuBits;
	UINT32          m_ena;

	UNSEventLogger *m_pLogger;

	// worker objects
	IPCiATStatus    m_IPCiATStatus;
	ATEvents::EventHistory m_eventHistory;

	Semaphore       m_dataSetSemaphore;
	bool            m_init;

	// data holders and analyzers
	AMTStatusData   m_amtStatusData;
	AMTStatusColl   m_AMTStatusColl;
	std::list<ATEvents::EventNode> m_amtEvents;
#ifdef WITH_TPM
	TPMStatusData   m_tpmStatusData;
	TPMStatusColl   m_TPMStatusColl;
	std::list<ATEvents::EventNode> m_tpmEvents;
#endif
	std::list<ATEvents::EventNode> m_asyncEvents;
};

#endif //_AT_STATUS_PROXY_H

