/*******************************************************************************
 * Part of "Intel(R) Active Management Technology (Intel(R) AMT)
 *                   User Notification Service (UNS)"
 *
 * Copyright (c) 2007 - 2008 Intel Corp.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions, and the following disclaimer,
 *    without modification.
 * 2. Redistributions in binary form must reproduce at minimum a disclaimer
 *    substantially similar to the "NO WARRANTY" disclaimer below
 *    ("Disclaimer") and any redistribution must be conditioned upon
 *    including a substantially similar Disclaimer requirement for further
 *    binary redistribution.
 * 3. Neither the names of the above-listed copyright holders nor the names
 *    of any contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * Alternatively, this software may be distributed under the terms of the
 * GNU General Public License ("GPL") version 2 as published by the Free
 * Software Foundation.
 *
 * NO WARRANTY
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR CONTRIBUTORS BE LIABLE FOR SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGES.
 *******************************************************************************/

#ifndef _EVENT_HISTORY_H
#define _EVENT_HISTORY_H

#include <ctime>
#include <string>
#include <list>

#include "EventNode.h"

namespace ATEvents
{

class EventHistory
{
public:
	static const std::string defaultEHFileName;
	static const std::string userEHStateFileName;

	typedef struct _Event {
		time_t ts;
		unsigned char id;
		unsigned char data[3];
	} Event;

	EventHistory();
	virtual ~EventHistory();

	bool Init(const std::string &filename = EventHistory::defaultEHFileName, unsigned int maxsize = 0);

	int AddEvent(unsigned char id, time_t ts = 0, unsigned char data1 = 0, unsigned char data2 = 0, unsigned char data3 = 0);
	int AddEvent(const EventNode &event);
	int AddEvents(const std::list<EventNode> &events);

	int GetEvents(std::list<EventNode> &events);
	int GetLastEvents(std::list<EventNode> &events, unsigned int maxRsize = 0x100, bool bigskip = true);

	int LoadUserLastEvent(EventNode &readEvent, EventNode &seenEvent);
	int SaveUserLastEvent(const EventNode &readEvent, const EventNode &seenEvent);

private:
	std::string m_fileName;
	std::string m_home;
	unsigned int m_maxSize;

	int checkShorten(unsigned int xsize);
	int addEvent(const Event &ev);
};

}

#endif //_EVENT_HISTORY_H
