/*******************************************************************************
 * Part of "Intel(R) Active Management Technology (Intel(R) AMT)
 *                   User Notification Service (UNS)"
 *
 * Copyright (c) 2007 - 2008 Intel Corp.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions, and the following disclaimer,
 *    without modification.
 * 2. Redistributions in binary form must reproduce at minimum a disclaimer
 *    substantially similar to the "NO WARRANTY" disclaimer below
 *    ("Disclaimer") and any redistribution must be conditioned upon
 *    including a substantially similar Disclaimer requirement for further
 *    binary redistribution.
 * 3. Neither the names of the above-listed copyright holders nor the names
 *    of any contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * Alternatively, this software may be distributed under the terms of the
 * GNU General Public License ("GPL") version 2 as published by the Free
 * Software Foundation.
 *
 * NO WARRANTY
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR CONTRIBUTORS BE LIABLE FOR SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGES.
 *******************************************************************************/

#ifndef _MEI_AMT_STATUS_H
#define _MEI_AMT_STATUS_H

#include "AMTStatusData.h"
#include "IMEAMTStatus.h"
#include "StatusCodeDefinitions.h"
#include "PTHICommand.h"
#include "FWULCommand.h"
#include <string>
#include <ctime>

class MEIAMTStatus : public IMEAMTStatus
{
public:
	// Constructor
	MEIAMTStatus(bool verbose = false);
	// dtor
	virtual ~MEIAMTStatus() {};

	/* Reader API */
	//initialize as reader
	bool InitReader() { return true; };
	//deinitialize reader
	void CloseReader() {};
	//get the status data
	bool GetAMTStatusData(AMTStatusData &statusData, bool useFWU = false);

	//set amt disabled state from external FWU
	void SetAMTDisabled(bool disabled) { m_wasAMTDisabled = disabled; };

protected:
	virtual bool isDebugEnabled() { return m_verbose; };
	virtual void debugLog(const char *msg) { if (isDebugEnabled()) { fprintf(stdout, "%s\n", msg); } };

private:
	int getAMTStatus();
	bool isAMTStatusDataAMTVersionValid();
	bool getAMTInfo();
	bool getAMTHECIInfo();
	bool getProvisioningState();
	bool getProvisioningMode();
	bool getFeaturesStatus(); //for Redirection and system defense state
	bool getWebUIState();
	bool getPowerPolicy();
	bool getLastHostResetReason();
	bool getMEResetReason();
	bool getNetworkSettings();
	bool getRemoteAccessStatus();
	bool getLmsVersion();
	bool getLmsVersionCached(time_t ttl = 120);
	bool checkAMTDisabled(bool useFWU);

	AMTStatusData m_AMTStatusData;
	PTHICommand pthiCommand;
	FWULCommand fwulCommand;
	bool m_wasAMTDisabled;
	bool m_verbose;

	time_t m_cachedLmsTs;
	bool   m_cachedLmsIsVer;
	char   m_cachedLmsVer[32];
};

#endif //_MEI_AMT_STATUS_H
