/*******************************************************************************
 * Part of "Intel(R) Active Management Technology (Intel(R) AMT)
 *                   User Notification Service (UNS)"
 *
 * Copyright (c) 2007 - 2008 Intel Corp.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions, and the following disclaimer,
 *    without modification.
 * 2. Redistributions in binary form must reproduce at minimum a disclaimer
 *    substantially similar to the "NO WARRANTY" disclaimer below
 *    ("Disclaimer") and any redistribution must be conditioned upon
 *    including a substantially similar Disclaimer requirement for further
 *    binary redistribution.
 * 3. Neither the names of the above-listed copyright holders nor the names
 *    of any contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * Alternatively, this software may be distributed under the terms of the
 * GNU General Public License ("GPL") version 2 as published by the Free
 * Software Foundation.
 *
 * NO WARRANTY
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR CONTRIBUTORS BE LIABLE FOR SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGES.
 *******************************************************************************/

//*****************************************************************************
//
// Class:	 UserNotificationServiceLinux
// Date created: 10 Feb 2007
// Description:	 The main class of the service.
//
//*****************************************************************************

#ifndef _USER_NOTIFICATION_SERVICE_H
#define _USER_NOTIFICATION_SERVICE_H

#include "UNSStatus.h"
#include "UNSEventLogger.h"
#include "UserNotificationThread.h"
#include "Credentials.h"
#ifdef WITH_AMTPP
#include "PostureRetrievalThread.h"
#endif
#include "ATStatus.h"
#include "AMTStatusThread.h"
#ifdef WITH_TPM
#include "TPMStatusThread.h"
#endif

#define BACKLOG			(100)	// Max. request backlog
#define	UNS_WAIT_TIME	5000	// Recover wait time.

class UserNotificationService
{
public:
	UserNotificationService();
	virtual ~UserNotificationService(void);

	// initialize logger and shares
	void InitLogger();

	// disable logger and shares
	void DeinitLogger();

	// Perform initialization tasks.
	unsigned long ServiceInitialization(unsigned long argc,
		const char **argv,
		unsigned long *specificError);

	// Set credentials from command line
	unsigned long SetCredentialsMode(unsigned long argc,
		const char **argv,
		unsigned long *specificError);

	// Parse Arguments
	unsigned long ParseArguments(int argc,
		const char **argv,
		Credentials **unsCreds
#ifdef WITH_AMTPP
		, Credentials **eacCreds
#endif
		, bool &clear);

	unsigned long UpdateRegistry(int argc, const char **argv);

	// Listen to incoming connections and process them.
	unsigned long Start();

	// Stop the service.
	void Stop();

#ifdef _DEBUG_MOST
	void setClientIP(const string &clip);
	void setServerIP(const string &svip);
#endif

private:
	// Stop the service.
	void InternalStop();


	ATStatus         m_ATStatus;

	// Data members.
	UNSEventLogger  *m_Logger;   // Used to log events.
#ifdef WITH_AMTPP
	PostureRetrievalThread m_PostureRetrievalThread;   // The NAC thread.
#endif
	UserNotificationThread m_UserNotificationThread;   // The UNS thread
	AMTStatusThread  m_AMTStatusThread;   // The AMTStatus thread.
#ifdef WITH_TPM
	TPMStatusThread  m_TPMStatusThread;   // The TPMStatus thread.
#endif

	bool             m_init;
	Semaphore        m_StopSemaphore;

	bool             m_isAMTEnabled;
	Semaphore        m_semIsAMTEnabled;
};

#endif
