/*******************************************************************************
 * Part of "Intel(R) Active Management Technology (Intel(R) AMT)
 *                   User Notification Service (UNS)"
 *
 * Copyright (c) 2007 - 2008 Intel Corp.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions, and the following disclaimer,
 *    without modification.
 * 2. Redistributions in binary form must reproduce at minimum a disclaimer
 *    substantially similar to the "NO WARRANTY" disclaimer below
 *    ("Disclaimer") and any redistribution must be conditioned upon
 *    including a substantially similar Disclaimer requirement for further
 *    binary redistribution.
 * 3. Neither the names of the above-listed copyright holders nor the names
 *    of any contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * Alternatively, this software may be distributed under the terms of the
 * GNU General Public License ("GPL") version 2 as published by the Free
 * Software Foundation.
 *
 * NO WARRANTY
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR CONTRIBUTORS BE LIABLE FOR SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGES.
 *******************************************************************************/

#ifndef __AMT_ENDPOINTACCESSCONTROLSERVICE_H
#define __AMT_ENDPOINTACCESSCONTROLSERVICE_H
#include "CIM_Service.h"
namespace CimClassNamespace
{

	// Class AMT_EndpointAccessControlService:
	// A AMT_EndpointAccessControlService is a Logical Element that contains the information necessary to represent and manage the functionality provided by a the Endpoint Access Control manager of Intel AMT.
	class AMT_EndpointAccessControlService  : public CIM_Service
	{
	public:
		// type definitions
		typedef CimClassContainer<AMT_EndpointAccessControlService> AMT_EndpointAccessControlServiceContainer;

		// static const declarations
		static const string CLASS_NAME;
		static const string CLASS_URI;
		static const string CLASS_NS;
		static const string CLASS_NS_PREFIX;

		// class fields
		// Invoke RequestStateChange Classes:
		// Requests that the state of the element be changed to the value specified in the RequestedState parameter. When the requested state change takes place, the EnabledState and RequestedState of the element will be the same. Invoking the RequestStateChange method multiple times could result in earlier requests being overwritten or lost.
		// If 0 is returned, then the task completed successfully and the use of ConcreteJob was not required. If 4096 (0x1000) is returned, then the task will take some time to complete, ConcreteJob will be created, and its reference returned in the output parameter Job. Any other return code indicates an error condition.
		class RequestStateChange_INPUT : public Serializable
		{
		public:
			// class fields
			// The state requested for the element. This information will be placed into the RequestedState property of the instance if the return code of the RequestStateChange method is 0 ('Completed with No Error'), 3 ('Timeout'), or 4096 (0x1000) ('Job Started'). Refer to the description of the EnabledState and RequestedState properties for the detailed explanations of the RequestedState values.
			// Legal values:
			// Enabled: 2
			// Disabled: 3
			// Shut Down: 4
			// Offline: 6
			// Test: 7
			// Defer: 8
			// Quiesce: 9
			// Reboot: 10
			// Reset: 11
			// DMTF Reserved: ..
			// Vendor Reserved: 32768..65535
			unsigned short RequestedState;

			// This field determines whether the RequestedState field is valid.
			bool RequestedStateSpecified;

			// A timeout period that specifies the maximum amount of time that the client expects the transition to the new state to take. The interval format must be used to specify the TimeoutPeriod. A value of 0 or a null parameter indicates that the client has no time requirements for the transition.
			// If this property does not contain 0 or null and the implementation does not support this parameter, a return code of 'Use Of Timeout Parameter Not Supported' must be returned.
			DateTime TimeoutPeriod;

			// This field determines whether the TimeoutPeriod field is valid.
			bool TimeoutPeriodSpecified;

			// Class Constructor
			RequestStateChange_INPUT();

			// Class Destructor
			~RequestStateChange_INPUT(){}

			// This function appends a serialization of this instance to the given node.
			void SerializeMembers(XMLElement& node) const;
		};

		class RequestStateChange_OUTPUT : public DeSerializable
		{
		public:
			// class fields
			// Reference to the job (can be null if the task is completed).
			EndpointReference Job;

			// This field determines whether the Job field is valid.
			bool JobSpecified;

			// Function Return Value:
			// Legal values:
			// Completed with No Error: 0
			// Not Supported: 1
			// Unknown or Unspecified Error: 2
			// Cannot complete within Timeout Period: 3
			// Failed: 4
			// Invalid Parameter: 5
			// In Use: 6
			// DMTF Reserved: ..
			// Method Parameters Checked - Job Started: 4096
			// Invalid State Transition: 4097
			// Use of Timeout Parameter Not Supported: 4098
			// Busy: 4099
			// Method Reserved: 4100..32767
			// Vendor Specific: 32768..65535
			unsigned int ReturnValue;

			// Class Constructor
			RequestStateChange_OUTPUT();

			// Class Destructor
			~RequestStateChange_OUTPUT(){}

		private:
			// This function sets a field value according to the given node.
			void SetValue(const XMLElement& elem);

			// This function clears the fields before deserialize is called.
			void ClearValues();

		};

		// Invoke GetPosture Classes:
		// This method returns (and optionally updates) the EAC posture for the Intel AMT device.
		class GetPosture_INPUT : public Serializable
		{
		public:
			// class fields
			// The posture type to be generated.
			// Legal values:
			// Attribute-Value pair (AVP) type: 0
			unsigned short PostureType;

			// Class Constructor
			GetPosture_INPUT();

			// Class Destructor
			~GetPosture_INPUT(){}

			// This function appends a serialization of this instance to the given node.
			void SerializeMembers(XMLElement& node) const;
		};

		class GetPosture_OUTPUT : public DeSerializable
		{
		public:
			// class fields
			// BLOB representation of a Signed NAC Posture data block.
			Base64 SignedPosture;

			// This field determines whether the SignedPosture field is valid.
			bool SignedPostureSpecified;

			// A computed hash value over the posture data (fields like current time is omitted). This hash can be used to check if the posture was changed, comparing to the last computed hash value.
			Base64 PostureChangeHash;

			// This field determines whether the PostureChangeHash field is valid.
			bool PostureChangeHashSpecified;

			// Function Return Value:
			// Legal values:
			// PT_STATUS_SUCCESS: 0
			// PT_STATUS_INTERNAL_ERROR: 1
			// PT_STATUS_INVALID_PARAMETER: 36
			// PT_STATUS_NO_ASSOCIATION: 2072
			unsigned int ReturnValue;

			// Class Constructor
			GetPosture_OUTPUT();

			// Class Destructor
			~GetPosture_OUTPUT(){}

		private:
			// This function sets a field value according to the given node.
			void SetValue(const XMLElement& elem);

			// This function clears the fields before deserialize is called.
			void ClearValues();

		};

		// Invoke GetPostureHash Classes:
		// This method returns an hash of the currently available posture for the Intel AMT device, which can be compared to hash values from previous results to detect differences.
		class GetPostureHash_INPUT : public Serializable
		{
		public:
			// class fields
			// The posture type to be generated.
			// Legal values:
			// Attribute-Value pair (AVP) type: 0
			unsigned short PostureType;

			// Class Constructor
			GetPostureHash_INPUT();

			// Class Destructor
			~GetPostureHash_INPUT(){}

			// This function appends a serialization of this instance to the given node.
			void SerializeMembers(XMLElement& node) const;
		};

		class GetPostureHash_OUTPUT : public DeSerializable
		{
		public:
			// class fields
			// A computed hash value over the posture data (fields like current time is omitted). This hash can be used to check if the posture was changed, comparing to the last computed hash value.
			Base64 PostureChangeHash;

			// This field determines whether the PostureChangeHash field is valid.
			bool PostureChangeHashSpecified;

			// Function Return Value:
			// Legal values:
			// PT_STATUS_SUCCESS: 0
			// PT_STATUS_INTERNAL_ERROR: 1
			// PT_STATUS_INVALID_PARAMETER: 36
			// PT_STATUS_NO_ASSOCIATION: 2072
			unsigned int ReturnValue;

			// Class Constructor
			GetPostureHash_OUTPUT();

			// Class Destructor
			~GetPostureHash_OUTPUT(){}

		private:
			// This function sets a field value according to the given node.
			void SetValue(const XMLElement& elem);

			// This function clears the fields before deserialize is called.
			void ClearValues();

		};

		// Invoke UpdatePostureState Classes:
		// This method updates the posture state for the Intel AMT device.
		class UpdatePostureState_INPUT : public Serializable
		{
		public:
			// class fields
			// The posture element to be updated.
			// Legal values:
			// PostureUpdateBootCounters: 0
			// PostureUpdateAgentPresenceState: 1
			unsigned short UpdateType;

			// Class Constructor
			UpdatePostureState_INPUT();

			// Class Destructor
			~UpdatePostureState_INPUT(){}

			// This function appends a serialization of this instance to the given node.
			void SerializeMembers(XMLElement& node) const;
		};

		class UpdatePostureState_OUTPUT : public DeSerializable
		{
		public:
			// class fields
			// Function Return Value:
			// Legal values:
			// PT_STATUS_SUCCESS: 0
			// PT_STATUS_INTERNAL_ERROR: 1
			// PT_STATUS_INVALID_PARAMETER: 36
			unsigned int ReturnValue;

			// Class Constructor
			UpdatePostureState_OUTPUT();

			// Class Destructor
			~UpdatePostureState_OUTPUT(){}

		private:
			// This function sets a field value according to the given node.
			void SetValue(const XMLElement& elem);

			// This function clears the fields before deserialize is called.
			void ClearValues();

		};

		// Invoke GetEacOptions Classes:
		// This method returns EAC options for the Intel AMT device.
		class GetEacOptions_INPUT : public Serializable
		{
		public:
			// class fields
			// Class Constructor
			GetEacOptions_INPUT();

			// Class Destructor
			~GetEacOptions_INPUT(){}

			// This function appends a serialization of this instance to the given node.
			void SerializeMembers(XMLElement& node) const;
		};

		class GetEacOptions_OUTPUT : public DeSerializable
		{
		public:
			// class fields
			// Enabled EAC Vendors
			// Legal values:
			// EAC NAC: 1
			// EAC NAP: 2
			// EAC NAC and NAP: 3
			// Reserved: 4..65535
			unsigned int EacVendors;

			// This field determines whether the EacVendors field is valid.
			bool EacVendorsSpecified;

			// Posture Hash Type
			// Legal values:
			// SHA-1-160: 1
			// Reserved: 2..65535
			unsigned int PostureHashAlgorithm;

			// This field determines whether the PostureHashAlgorithm field is valid.
			bool PostureHashAlgorithmSpecified;

			// Function Return Value:
			// Legal values:
			// PT_STATUS_SUCCESS: 0
			// PT_STATUS_INTERNAL_ERROR: 1
			unsigned int ReturnValue;

			// Class Constructor
			GetEacOptions_OUTPUT();

			// Class Destructor
			~GetEacOptions_OUTPUT(){}

		private:
			// This function sets a field value according to the given node.
			void SetValue(const XMLElement& elem);

			// This function clears the fields before deserialize is called.
			void ClearValues();

		};

		// Invoke SetEacOptions Classes:
		// This method configures EAC options for the Intel AMT device.
		class SetEacOptions_INPUT : public Serializable
		{
		public:
			// class fields
			// Enabled EAC Vendors
			// Legal values:
			// EAC NAC: 1
			// EAC NAP: 2
			// EAC NAC and NAP: 3
			// Reserved: 4..65535
			unsigned int EacVendors;

			// Posture Hash Method
			// Legal values:
			// SHA-1-160: 1
			// Reserved: 2..65535
			unsigned int PostureHashAlgorithm;

			// Class Constructor
			SetEacOptions_INPUT();

			// Class Destructor
			~SetEacOptions_INPUT(){}

			// This function appends a serialization of this instance to the given node.
			void SerializeMembers(XMLElement& node) const;
		};

		class SetEacOptions_OUTPUT : public DeSerializable
		{
		public:
			// class fields
			// Function Return Value:
			// Legal values:
			// PT_STATUS_SUCCESS: 0
			// PT_STATUS_INTERNAL_ERROR: 1
			// PT_STATUS_INVALID_PARAMETER: 36
			// PT_STATUS_FLASH_WRITE_LIMIT_EXCEEDED: 38
			// PT_STATUS_AUDIT_FAIL: 2075
			unsigned int ReturnValue;

			// Class Constructor
			SetEacOptions_OUTPUT();

			// Class Destructor
			~SetEacOptions_OUTPUT(){}

		private:
			// This function sets a field value according to the given node.
			void SetValue(const XMLElement& elem);

			// This function clears the fields before deserialize is called.
			void ClearValues();

		};

	private:
		// This function sets a field value according to the given node.
		virtual void SetValue(const XMLElement& node);

		// This function Clears the settings of the instance, before deserialization.
		virtual void ClearValues();

	public:
		// Class Constructor
		AMT_EndpointAccessControlService(
			const string& objName = AMT_EndpointAccessControlService::CLASS_NAME,
			const string& uri = AMT_EndpointAccessControlService::CLASS_URI,
			const string& ns = AMT_EndpointAccessControlService::CLASS_NS,
			const string& nsPrefix = AMT_EndpointAccessControlService::CLASS_NS_PREFIX);

		// Class Destructor
		virtual ~AMT_EndpointAccessControlService(){}

		// This function appends a serialization of this instance to the given node.
		virtual void SerializeMembers(XMLElement& node) const;

		// This function returns the selector set of this instance.
		virtual NameValuePairs GetSelectorsList() const;

		// This function performs the Invoke RequestStateChange operation using the given input.
		// The output of the function is returned in the given output class.
		virtual void InvokeRequestStateChange(RequestStateChange_INPUT &input, RequestStateChange_OUTPUT &output,  const WsmanClient *cl = defaultProvider) const;

		// This function performs the Invoke GetPosture operation using the given input.
		// The output of the function is returned in the given output class.
		virtual void InvokeGetPosture(GetPosture_INPUT &input, GetPosture_OUTPUT &output,  const WsmanClient *cl = defaultProvider) const;

		// This function performs the Invoke GetPostureHash operation using the given input.
		// The output of the function is returned in the given output class.
		virtual void InvokeGetPostureHash(GetPostureHash_INPUT &input, GetPostureHash_OUTPUT &output,  const WsmanClient *cl = defaultProvider) const;

		// This function performs the Invoke UpdatePostureState operation using the given input.
		// The output of the function is returned in the given output class.
		virtual void InvokeUpdatePostureState(UpdatePostureState_INPUT &input, UpdatePostureState_OUTPUT &output,  const WsmanClient *cl = defaultProvider) const;

		// This function performs the Invoke GetEacOptions operation using the given input.
		// The output of the function is returned in the given output class.
		virtual void InvokeGetEacOptions(GetEacOptions_INPUT &input, GetEacOptions_OUTPUT &output,  const WsmanClient *cl = defaultProvider) const;

		// This function performs the Invoke SetEacOptions operation using the given input.
		// The output of the function is returned in the given output class.
		virtual void InvokeSetEacOptions(SetEacOptions_INPUT &input, SetEacOptions_OUTPUT &output,  const WsmanClient *cl = defaultProvider) const;

	};
}
#endif
