/*******************************************************************************
 * Part of "Intel(R) Active Management Technology (Intel(R) AMT)
 *                   User Notification Service (UNS)"
 *
 * Copyright (c) 2007 - 2008 Intel Corp.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions, and the following disclaimer,
 *    without modification.
 * 2. Redistributions in binary form must reproduce at minimum a disclaimer
 *    substantially similar to the "NO WARRANTY" disclaimer below
 *    ("Disclaimer") and any redistribution must be conditioned upon
 *    including a substantially similar Disclaimer requirement for further
 *    binary redistribution.
 * 3. Neither the names of the above-listed copyright holders nor the names
 *    of any contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * Alternatively, this software may be distributed under the terms of the
 * GNU General Public License ("GPL") version 2 as published by the Free
 * Software Foundation.
 *
 * NO WARRANTY
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR CONTRIBUTORS BE LIABLE FOR SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGES.
 *******************************************************************************/

#ifndef __CIM_ENABLEDLOGICALELEMENT_H
#define __CIM_ENABLEDLOGICALELEMENT_H
#include "CIM_LogicalElement.h"
namespace CimClassNamespace
{

	// Class CIM_EnabledLogicalElement:
	// This class extends LogicalElement to abstract the concept of an element that is enabled and disabled, such as a LogicalDevice or a ServiceAccessPoint.
	class CIM_EnabledLogicalElement  : public CIM_LogicalElement
	{
	public:
		// type definitions
		typedef CimClassContainer<CIM_EnabledLogicalElement> CIM_EnabledLogicalElementContainer;

		// static const declarations
		static const string CLASS_NAME;
		static const string CLASS_URI;
		static const string CLASS_NS;
		static const string CLASS_NS_PREFIX;

		// class fields
		// EnabledState is an integer enumeration that indicates the enabled and disabled states of an element. It can also indicate the transitions between these requested states. For example, shutting down (value=4) and starting (value=10) are transient states between enabled and disabled. The following text briefly summarizes the various enabled and disabled states:
		// Enabled (2) indicates that the element is or could be executing commands, will process any queued commands, and queues new requests.
		// Disabled (3) indicates that the element will not execute commands and will drop any new requests.
		// Shutting Down (4) indicates that the element is in the process of going to a Disabled state.
		// Not Applicable (5) indicates the element does not support being enabled or disabled.
		// Enabled but Offline (6) indicates that the element might be completing commands, and will drop any new requests.
		// Test (7) indicates that the element is in a test state.
		// Deferred (8) indicates that the element might be completing commands, but will queue any new requests.
		// Quiesce (9) indicates that the element is enabled but in a restricted mode.
		// Starting (10) indicates that the element is in the process of going to an Enabled state. New requests are queued.
		// Legal values:
		// Unknown: 0
		// Other: 1
		// Enabled: 2
		// Disabled: 3
		// Shutting Down: 4
		// Not Applicable: 5
		// Enabled but Offline: 6
		// In Test: 7
		// Deferred: 8
		// Quiesce: 9
		// Starting: 10
		// DMTF Reserved: 11..32767
		// Vendor Reserved: 32768..65535
		unsigned short EnabledState;

		// This field determines whether the EnabledState field is valid.
		bool EnabledStateSpecified;

		// A string that describes the enabled or disabled state of the element when the EnabledState property is set to 1 ("Other"). This property must be set to null when EnabledState is any value other than 1.
		string OtherEnabledState;

		// This field determines whether the OtherEnabledState field is valid.
		bool OtherEnabledStateSpecified;

		// RequestedState is an integer enumeration that indicates the last requested or desired state for the element. The actual state of the element is represented by EnabledState. This property is provided to compare the last requested and current enabled or disabled states. Note that when EnabledState is set to 5 ("Not Applicable"), then this property has no meaning. By default, the RequestedState of the element is 5 ("No Change"). Refer to the EnabledState property description for explanations of the values in the RequestedState enumeration.
		// Offline (6) indicates that the element has been requested to transition to the Enabled but Offline EnabledState.
		// It should be noted that there are two new values in RequestedState that build on the statuses of EnabledState. These are "Reboot" (10) and "Reset" (11). Reboot refers to doing a "Shut Down" and then moving to an "Enabled" state. Reset indicates that the element is first "Disabled" and then "Enabled". The distinction between requesting "Shut Down" and "Disabled" should also be noted. Shut Down requests an orderly transition to the Disabled state, and might involve removing power, to completely erase any existing state. The Disabled state requests an immediate disabling of the element, such that it will not execute or accept any commands or processing requests.
		//
		// This property is set as the result of a method invocation (such as Start or StopService on CIM_Service), or can be overridden and defined as WRITEable in a subclass. The method approach is considered superior to a WRITEable property, because it allows an explicit invocation of the operation and the return of a result code.
		//
		// A particular instance of EnabledLogicalElement might not support RequestedStateChange. If this occurs, the value 12 ("Not Applicable") is used.
		// Legal values:
		// Enabled: 2
		// Disabled: 3
		// Shut Down: 4
		// No Change: 5
		// Offline: 6
		// Test: 7
		// Deferred: 8
		// Quiesce: 9
		// Reboot: 10
		// Reset: 11
		// Not Applicable: 12
		// DMTF Reserved: ..
		// Vendor Reserved: 32768..65535
		unsigned short RequestedState;

		// This field determines whether the RequestedState field is valid.
		bool RequestedStateSpecified;

		// An enumerated value indicating an administrator's default or startup configuration for the Enabled State of an element. By default, the element is "Enabled" (value=2).
		// Legal values:
		// Enabled: 2
		// Disabled: 3
		// Not Applicable: 5
		// Enabled but Offline: 6
		// No Default: 7
		// Quiesce: 9
		// DMTF Reserved: ..
		// Vendor Reserved: 32768..65535
		unsigned short EnabledDefault;

		// This field determines whether the EnabledDefault field is valid.
		bool EnabledDefaultSpecified;

		// The date or time when the EnabledState of the element last changed. If the state of the element has not changed and this property is populated, then it must be set to a 0 interval value. If a state change was requested, but rejected or not yet processed, the property must not be updated.
		DateTime TimeOfLastStateChange;

		// This field determines whether the TimeOfLastStateChange field is valid.
		bool TimeOfLastStateChangeSpecified;

		// PrimaryStatus provides a high level status value, intended to align with Red-Yellow-Green type representation of status. It should be used in conjunction with DetailedStatus to provide high level and detailed health status of the ManagedElement and its subcomponents.
		// PrimaryStatus consists of one of the following values: Unknown, OK, Degraded or Error. "Unknown" indicates the implementation is in general capable of returning this property, but is unable to do so at this time.
		// "OK" indicates the ManagedElement is functioning normally.
		// "Degraded" indicates the ManagedElement is functioning below normal.
		// "Error" indicates the ManagedElement is in an Error condition.
		// Legal values:
		// Unknown: 0
		// OK: 1
		// Degraded: 2
		// Error: 3
		// DMTF Reserved: ..
		// Vendor Reserved: 0x8000..
		unsigned short PrimaryStatus;

		// This field determines whether the PrimaryStatus field is valid.
		bool PrimaryStatusSpecified;

		// DetailedStatus compliments PrimaryStatus with additional status detail. It consists of one of the following values: Not Available, No Additional Information, Stressed, Predictive Failure, Error, Non-Recoverable Error, SupportingEntityInError. Detailed status is used to expand upon the PrimaryStatus of the element.
		// A Null return indicates the implementation (provider) does not implement this property.
		// "Not Available" indicates that the implementation (provider) is capable of returning a value for this property, but not ever for this particular piece of hardware/software or the property is intentionally not used because it adds no meaningful information (as in the case of a property that is intended to add additional info to another property).
		// "No Additional Information" indicates that the element is functioning normally as indicated by PrimaryStatus = "OK".
		// "Stressed" indicates that the element is functioning, but needs attention. Examples of "Stressed" states are overload, overheated, and so on.
		// "Predictive Failure" indicates that an element is functioning normally but a failure is predicted in the near future.
		// "Non-Recoverable Error " indicates that this element is in an error condition that requires human intervention.
		// "Supporting Entity in Error" indicates that this element might be "OK" but that another element, on which it is dependent, is in error. An example is a network service or endpoint that cannot function due to lower-layer networking problems.
		// Legal values:
		// Not Available: 0
		// No Additional Information: 1
		// Stressed: 2
		// Predictive Failure: 3
		// Non-Recoverable Error: 4
		// Supporting Entity in Error: 5
		// DMTF Reserved: ..
		// Vendor Reserved: 0x8000..
		unsigned short DetailedStatus;

		// This field determines whether the DetailedStatus field is valid.
		bool DetailedStatusSpecified;

		// OperatingStatus provides a current status value for the operational condition of the element and can be used for providing more detail with respect to the value of EnabledState. It can also provide the transitional states when an element is transitioning from one state to another, such as when an element is transitioning between EnabledState and RequestedState, as well as other transitional conditions.
		// OperatingStatus consists of one of the following values: Unknown, Not Available, In Service, Starting, Stopping, Stopped, Aborted, Dormant, Completed, Migrating, Emmigrating, Immigrating, Snapshotting. Shutting Down, In Test
		// A Null return indicates the implementation (provider) does not implement this property.
		// "Unknown" indicates the implementation is in general capable of returning this property, but is unable to do so at this time.
		// "None" indicates that the implementation (provider) is capable of returning a value for this property, but not ever for this particular piece of hardware/software or the property is intentionally not used because it adds no meaningful information (as in the case of a property that is intended to add additional info to another property).
		// "In Service" describes an element being configured, maintained, cleaned, or otherwise administered.
		// "Starting" describes an element being initialized.
		// "Stopping" describes an element being brought to an orderly stop.
		// "Stopped" and "Aborted" are similar, although the former implies a clean and orderly stop, while the latter implies an abrupt stop where the state and configuration of the element might need to be updated.
		// "Dormant" indicates that the element is inactive or quiesced.
		// "Completed" indicates that the element has completed its operation. This value should be combined with either OK, Error, or Degraded in the PrimaryStatus so that a client can tell if the complete operation Completed with OK (passed), Completed with Error (failed), or Completed with Degraded (the operation finished, but it did not complete OK or did not report an error).
		// "Migrating" element is being moved between host elements.
		// "Immigrating" element is being moved to new host element.
		// "Emigrating" element is being moved away from host element.
		// "Shutting Down" describes an element being brought to an abrupt stop.
		// "In Test" element is performing test functions.
		// Legal values:
		// Unknown: 0
		// Not Available: 1
		// In Service: 2
		// Starting: 3
		// Stopping: 4
		// Stopped: 5
		// Aborted: 6
		// Dormant: 7
		// Completed: 8
		// Migrating: 9
		// Emigrating: 10
		// Immigrating: 11
		// Snapshotting: 12
		// Shutting Down: 13
		// In Test: 14
		// DMTF Reserved: ..
		// Vendor Reserved: 0x8000..
		unsigned short OperatingStatus;

		// This field determines whether the OperatingStatus field is valid.
		bool OperatingStatusSpecified;

		// CommunicationStatus indicates the ability of the instrumentation to communicate with the underlying ManagedElement. CommunicationStatus consists of one of the following values: Unknown, None, Communication OK, Lost Communication, or No Contact.
		// A Null return indicates the implementation (provider) does not implement this property.
		// "Unknown" indicates the implementation is in general capable of returning this property, but is unable to do so at this time.
		// "Not Available" indicates that the implementation (provider) is capable of returning a value for this property, but not ever for this particular piece of hardware/software or the property is intentionally not used because it adds no meaningful information (as in the case of a property that is intended to add additional info to another property).
		// "Communication OK " indicates communication is established with the element, but does not convey any quality of service.
		// "No Contact" indicates that the monitoring system has knowledge of this element, but has never been able to establish communications with it.
		// "Lost Communication" indicates that the Managed Element is known to exist and has been contacted successfully in the past, but is currently unreachable.
		// Legal values:
		// Unknown: 0
		// Not Available: 1
		// Communication OK: 2
		// Lost Communication: 3
		// No Contact: 4
		// DMTF Reserved: ..
		// Vendor Reserved: 0x8000..
		unsigned short CommunicationStatus;

		// This field determines whether the CommunicationStatus field is valid.
		bool CommunicationStatusSpecified;

		// Invoke RequestStateChange Classes:
		// Requests that the state of the element be changed to the value specified in the RequestedState parameter. When the requested state change takes place, the EnabledState and RequestedState of the element will be the same. Invoking the RequestStateChange method multiple times could result in earlier requests being overwritten or lost.
		// If 0 is returned, then the task completed successfully and the use of ConcreteJob was not required. If 4096 (0x1000) is returned, then the task will take some time to complete, ConcreteJob will be created, and its reference returned in the output parameter Job. Any other return code indicates an error condition.
		class RequestStateChange_INPUT : public Serializable
		{
		public:
			// class fields
			// The state requested for the element. This information will be placed into the RequestedState property of the instance if the return code of the RequestStateChange method is 0 ('Completed with No Error'), 3 ('Timeout'), or 4096 (0x1000) ('Job Started'). Refer to the description of the EnabledState and RequestedState properties for the detailed explanations of the RequestedState values.
			// Legal values:
			// Enabled: 2
			// Disabled: 3
			// Shut Down: 4
			// Offline: 6
			// Test: 7
			// Defer: 8
			// Quiesce: 9
			// Reboot: 10
			// Reset: 11
			// DMTF Reserved: ..
			// Vendor Reserved: 32768..65535
			unsigned short RequestedState;

			// This field determines whether the RequestedState field is valid.
			bool RequestedStateSpecified;

			// A timeout period that specifies the maximum amount of time that the client expects the transition to the new state to take. The interval format must be used to specify the TimeoutPeriod. A value of 0 or a null parameter indicates that the client has no time requirements for the transition.
			// If this property does not contain 0 or null and the implementation does not support this parameter, a return code of 'Use Of Timeout Parameter Not Supported' must be returned.
			DateTime TimeoutPeriod;

			// This field determines whether the TimeoutPeriod field is valid.
			bool TimeoutPeriodSpecified;

			// Class Constructor
			RequestStateChange_INPUT();

			// Class Destructor
			~RequestStateChange_INPUT(){}

			// This function appends a serialization of this instance to the given node.
			void SerializeMembers(XMLElement& node) const;
		};

		class RequestStateChange_OUTPUT : public DeSerializable
		{
		public:
			// class fields
			// Reference to the job (can be null if the task is completed).
			EndpointReference Job;

			// This field determines whether the Job field is valid.
			bool JobSpecified;

			// Function Return Value:
			// Legal values:
			// Completed with No Error: 0
			// Not Supported: 1
			// Unknown or Unspecified Error: 2
			// Cannot complete within Timeout Period: 3
			// Failed: 4
			// Invalid Parameter: 5
			// In Use: 6
			// DMTF Reserved: ..
			// Method Parameters Checked - Job Started: 4096
			// Invalid State Transition: 4097
			// Use of Timeout Parameter Not Supported: 4098
			// Busy: 4099
			// Method Reserved: 4100..32767
			// Vendor Specific: 32768..65535
			unsigned int ReturnValue;

			// Class Constructor
			RequestStateChange_OUTPUT();

			// Class Destructor
			~RequestStateChange_OUTPUT(){}

		private:
			// This function sets a field value according to the given node.
			void SetValue(const XMLElement& elem);

			// This function clears the fields before deserialize is called.
			void ClearValues();

		};

	private:
		// This function sets a field value according to the given node.
		virtual void SetValue(const XMLElement& node);

		// This function Clears the settings of the instance, before deserialization.
		virtual void ClearValues();

	public:
		// Class Constructor
		CIM_EnabledLogicalElement(
			const string& objName = CIM_EnabledLogicalElement::CLASS_NAME,
			const string& uri = CIM_EnabledLogicalElement::CLASS_URI,
			const string& ns = CIM_EnabledLogicalElement::CLASS_NS,
			const string& nsPrefix = CIM_EnabledLogicalElement::CLASS_NS_PREFIX);

		// Class Destructor
		virtual ~CIM_EnabledLogicalElement(){}

		// This function appends a serialization of this instance to the given node.
		virtual void SerializeMembers(XMLElement& node) const;

		// This function returns the selector set of this instance.
		virtual NameValuePairs GetSelectorsList() const;

		// This function performs the Invoke RequestStateChange operation using the given input.
		// The output of the function is returned in the given output class.
		virtual void InvokeRequestStateChange(RequestStateChange_INPUT &input, RequestStateChange_OUTPUT &output,  const WsmanClient *cl = defaultProvider) const;

	};
}
#endif
